@import 'variables';
@import 'mixins';

/*************************
 * A. Main Theme styles
 *
 *  01. Extended style rules
 *  02. Reset styles
 *  03. Base theme styles
 *      03.01 body & html 
 *      03.02 Basic elements (a, p, b, blockquote etc)
 *      03.03 Headings h1-h6
 *      03.04 Tables
 *      
 *  04. Icons
 *      04.01 Ion icons
 *      04.02 Loading spinner
 *      
 *  05. Base elements
 *      05.01 Responsive headings
 *      05.02 Dropdown arrow/caret
 *      05.03 Modals
 *      05.04 Screen reader text
 *      05.05 Scroll to top button
 *      05.06 Social Icons
 *      05.07 Media Elements
 *      
 *  06. Site Header styles
 *      06.01 Base nav li elements
 *      06.02 site-header & site-navigation
 *      06.03 Dropdowns
 *      06.04 Header icons
 *      06.05 Navbar + children
 *      06.06 Mobile & auto-collapse
 *      06.07 Header's main color schemes
 *      06.08 Transparent header
 *      06.10 Sticky header
 *      06.11 Mega menu
 *          06.11.1 Full width mega menu
 *          06.11.2 Auto width mega menu
 *      06.12 Top bar
 *      06.13 Side panels
 * 
 *  07. Page header styles
 *      07.01 Page cover
 *      07.02 Page header
 *      
 *  08. Widgets styles
 *      08.01 Global widget styles
 *      08.02 Widget titles
 *      08.03 Horizontal menu in widget
 *      08.04 Widgets
 *          08.04.1 Tag Cloud
 *          08.04.2 Calendar
 *          08.04.3 Categories & Archive
 *          08.04.4 RSS Feed
 *          08.04.5 Recent Posts
 *          08.04.6 Recent Comments
 *          08.04.7 Product search
 *          08.04.8 Product rating
 *          08.04.9 Flickr images
 *          08.04.10 Text widget (HTML)
 *          08.04.11 Image widget
 *          08.04.12 Video widget
 * 
 *  09. Sidebars styles
 *  10. Footer styling
 *  11. Page sections
 *      11.01 Sections layout
 *      11.02 Sections default colors
 *      11.03 Sections shadows
 *      11.04 Sections child elements
 *      11.05 Section via shortcode
 *      
 *  12. Containers structure
 *      12.01 Container widths and LR padding
 *      12.02 Wrapper margins
 *      12.03 Small screens (stacked) tweaks
 *  
 *************************/

@import 'extends';
@import 'reset';
@import 'base';
@import 'icons';
@import 'base-elements';
@import 'header';
@import 'page-header';
@import 'widgets';
@import 'sidebar';
@import 'footer';
@import 'sections';
@import 'containers';

/*************************
 * B. Vendor styles
 *************************/

@import '../vendor/swiper';
@import '../vendor/photoswipe/main.scss';
@import '../vendor/photoswipe/default-skin/default-skin.scss';

/*************************
 * C. Elements
 * 
 *  13. Form elements styling
 *      13.01 Base form elements
 *      13.02 Buttons
 *      13.03 Search forms
 *      13.04 Comment forms
 *      13.05 Search form on 404 page
 *      
 *  14. External (vendor) elements styling
 *      14.01 Photoswipe style tweaks
 *      14.02 Swiper style tweaks
 *      14.03 Slab text styles
 *      14.04 YITH Plugins styling
 *          14.04.1 wcas - ajax search
 *          14.04.2 Wishlist
 *          14.04.3 Magnifier
 *          14.04.4 Quickview
 *      14.05 Mailchimp plugin
 *      14.06 Ninja forms
 *      14.07 WPML
 *      14.08 Instagram widget plugin
 *      14.09 Flexslider styles
 *      14.10 WooCommerce Variation swatches
 *      14.11 SearchWP Live Ajax Search 
 *      14.12 WC Ajax Product Filter
 *      
 *  15. Shortcode elements styling
 *      15.01 Social icons
 *      15.02 WP Gallery
 *      15.03 Dropcaps
 *      15.04 Styled maps
 *      15.05 Quotes
 *      15.06 Testimonials 
 *      15.07 Simple headings
 *      15.08 Banner
 *      15.09 WC cat-products slider
 *      15.10 Video popup
 *      
 *  16. Visual composer elements styling
 *      16.01 VC row fix
 *      16.02 VC buttons
 *      16.03 VC separator
 *      16.04 VC message box
 *      16.05 VC Tabs, Accordion & Tour
 *      16.06 VC Progress bars
 *      16.07 VC Toggles
 *      16.08 VC Pie chart
 *      16.08 VC Posts slider
 *      16.09 VC Icons
 *      16.10 VC Images
 *      16.11 VC Text element
 *      16.12 VC WC products shortcodes
 *      16.13 VC grid item
 * 
 *  17. Blog styling
 *      17.01 Base blog styles
 *      17.02 Blog posts
 *          17.02.1 Article thumbnail
 *          17.02.2 Article headings
 *          17.02.3 Article meta
 *          17.02.4 Article content
 *          17.02.5 Article edit & more links
 *          17.02.6 Sticky post extra styling
 *      17.03 Attachment posts
 *      17.04 Posts navigation
 *  
 *************************/

@import 'forms';
@import 'external';
@import 'shortcodes';
@import 'vc';
@import 'blog';

/*************************
 * D. Woocommerce styles
 * 
 *  18. woocommerce.scss
 *      18.01 Global styles
 *      18.02 Utility classes
 *      18.03 Main WooCommerce styles
 *          18.03.1 Product Page
 *          18.03.2 Product loops
 *          18.03.3 WC navigation
 *          18.03.4 Buttons
 *          18.03.5 Reviews
 *          18.03.6 Star ratings
 *          18.03.7 Tables
 *          18.03.8 Cart sidebar
 *          18.03.9 Forms
 *          18.03.10 Order page
 *          18.03.11 Layered nav widget
 *          18.03.12 Price filter widget
 *      18.04 Account page
 *      18.05 Cart page
 *      18.06 Checkout
 *      
 *  19. woocommerce-layout.scss
 *      19.01 General layout styles
 *      19.02 Product page
 *      19.03 Product loops
 *      19.04 Cart page
 *      19.05 Cart sidebar
 *      19.06 Forms
 *
 *  20. woocommerce-smallscreen.scss
 *      20.01 Small screens
 *      20.02 XSmall screens
 *          20.02.1 Tables
 *          20.02.3 General layout
 *          20.02.3 Products
 *          20.02.4 Product Details
 *          20.02.5 Cart
 *          20.02.6 Checkout
 *          20.02.7 Account
 *      20.03 XXSmall screens
 *      
 *  21. woocommerce-shrk.scss
 *      21.01 Header dropdown cart
 *      21.02 WC + Swiper
 *      
 *************************/
 
@import 'woocommerce/woocommerce';
@import 'woocommerce/woocommerce-layout';
@import 'woocommerce/woocommerce-smallscreen';
@import 'woocommerce/woocommerce-shrk';